##  Applicable Use Cases
[Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.") and [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX.") are two examples of larger transformation use cases where modeling initiatives make sense the most. Using initiatives in combination with the objective fact sheet and the SAP LeanIX Architecture and Road Map Planning allows organizations to get full transparency of their initiatives' impact on the entire enterprise architecture, which is complementary to a project portfolio management tool that describes initiatives (projects, epics, etc.) on a much more detailed level.
